@@ -84,6 +84,8 @@ class Event(models.Model):
     def save(self):
         if self.all_day_event:
             self.start_date_time = self.start_date_time.replace(hour=0, minute=0, second=0, microsecond=0)
+            if not self.end_date_time:
+                self.end_date_time = self.start_date_time
             self.end_date_time = self.end_date_time.replace(hour=23, minute=59, second=59, microsecond=0)
 
         super(Event, self).save()
